@@ -1,4 +1,21 @@
-# -*- coding: utf-8 -*-
+#
+# Licensed to Xatabase, Inc under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Xatabase, Inc licenses this file to you under the
+# Apache License, Version 2.0 (the "License"); you may not
+# use this file except in compliance with the License. You
+# may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+#
 
 import json
 import os
@@ -29,7 +46,7 @@ from .namespaces.workspace.table import Table
 
 # TODO this is a manual task, to keep in sync with pyproject.toml
 # could/should be automated to keep in sync
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 PERSONAL_API_KEY_LOCATION = "~/.config/xata/key"
 DEFAULT_BASE_URL_DOMAIN = "xata.sh"
@@ -194,6 +211,22 @@ class XataClient:
         # TODO: resolve branch name by the current git branch
         return os.environ.get("XATA_BRANCH")
 
+    def get_db_branch_name(self, db_name: str = None, branch_name: str = None) -> str:
+        """
+        Get Database with branch name, format: {db_name}:{branch_name}
+        The name can be build with passed params or from config or a combination of both
+
+        :param db_name: str
+        :branch_name: str
+
+        :return str
+        """
+        if db_name is None:
+            db_name = self.get_config()["dbName"]
+        if branch_name is None:
+            branch_name = self.get_config()["branchName"]
+        return f"{db_name}:{branch_name}"
+
     def request(self, method, urlPath, cp=False, headers={}, expect_codes=[], **kwargs):
         headers = {
             **headers,
@@ -309,7 +342,6 @@ class XataClient:
     def set_db_and_branch_names(self, db_name: str = None, branch_name: str = None):
         if db_name is not None:
             self.db_name = db_name
-
         if branch_name is not None:
             self.branch_name = branch_name
 
