@@ -1,3 +1,22 @@
+#
+# Licensed to Xatabase, Inc under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Xatabase, Inc licenses this file to you under the
+# Apache License, Version 2.0 (the "License"); you may not
+# use this file except in compliance with the License. You
+# may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+#
+
 # ------------------------------------------------------- #
 # Authentication
 # Authentication and API Key management.
@@ -23,6 +42,7 @@ class Authentication(Namespace):
         path: /user/keys
         method: GET
 
+
         :return Response
         """
         url_path = "/user/keys"
@@ -34,7 +54,8 @@ class Authentication(Namespace):
         path: /user/keys/{key_name}
         method: POST
 
-        :param key_name: str API Key name
+        :param key_name: str API Key name [in: path, req: True]
+
         :return Response
         """
         url_path = f"/user/keys/{key_name}"
@@ -46,7 +67,8 @@ class Authentication(Namespace):
         path: /user/keys/{key_name}
         method: DELETE
 
-        :param key_name: str API Key name
+        :param key_name: str API Key name [in: path, req: True]
+
         :return Response
         """
         url_path = f"/user/keys/{key_name}"
