@@ -1,3 +1,22 @@
+#
+# Licensed to Xatabase, Inc under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Xatabase, Inc licenses this file to you under the
+# Apache License, Version 2.0 (the "License"); you may not
+# use this file except in compliance with the License. You
+# may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+#
+
 # ------------------------------------------------------- #
 # Users
 # Users management
@@ -23,6 +42,7 @@ class Users(Namespace):
         path: /user
         method: GET
 
+
         :return Response
         """
         url_path = "/user"
@@ -34,12 +54,13 @@ class Users(Namespace):
         path: /user
         method: PUT
 
-        :param payload: dict Request Body
+        :param payload: dict content [in: requestBody, req: True]
+
         :return Response
         """
         url_path = "/user"
         headers = {"content-type": "application/json"}
-        return self.request("PUT", url_path, payload, headers)
+        return self.request("PUT", url_path, headers, payload)
 
     def deleteUser(
         self,
@@ -49,6 +70,7 @@ class Users(Namespace):
         path: /user
         method: DELETE
 
+
         :return Response
         """
         url_path = "/user"
