@@ -1,3 +1,22 @@
+#
+# Licensed to Xatabase, Inc under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Xatabase, Inc licenses this file to you under the
+# Apache License, Version 2.0 (the "License"); you may not
+# use this file except in compliance with the License. You
+# may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
+#
+
 # ------------------------------------------------------- #
 # Search_and_filter
 # APIs for searching, querying, filtering, and aggregating records.
@@ -776,14 +795,15 @@ class Search_and_filter(Namespace):
                path: /db/{db_branch_name}/tables/{table_name}/query
                method: POST
 
-               :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`.
-               :param table_name: str The Table name
-               :param payload: dict Request Body
+               :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
+               :param table_name: str The Table name [in: path, req: True]
+               :param payload: dict content [in: requestBody, req: True]
+
                :return Response
         """
         url_path = f"/db/{db_branch_name}/tables/{table_name}/query"
         headers = {"content-type": "application/json"}
-        return self.request("POST", url_path, payload, headers)
+        return self.request("POST", url_path, headers, payload)
 
     def searchBranch(self, db_branch_name: str, payload: dict) -> Response:
         """
@@ -791,13 +811,14 @@ class Search_and_filter(Namespace):
         path: /db/{db_branch_name}/search
         method: POST
 
-        :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`.
-        :param payload: dict Request Body
+        :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
+        :param payload: dict content [in: requestBody, req: True]
+
         :return Response
         """
         url_path = f"/db/{db_branch_name}/search"
         headers = {"content-type": "application/json"}
-        return self.request("POST", url_path, payload, headers)
+        return self.request("POST", url_path, headers, payload)
 
     def searchTable(
         self, db_branch_name: str, table_name: str, payload: dict
@@ -811,14 +832,15 @@ class Search_and_filter(Namespace):
                path: /db/{db_branch_name}/tables/{table_name}/search
                method: POST
 
-               :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`.
-               :param table_name: str The Table name
-               :param payload: dict Request Body
+               :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
+               :param table_name: str The Table name [in: path, req: True]
+               :param payload: dict content [in: requestBody, req: True]
+
                :return Response
         """
         url_path = f"/db/{db_branch_name}/tables/{table_name}/search"
         headers = {"content-type": "application/json"}
-        return self.request("POST", url_path, payload, headers)
+        return self.request("POST", url_path, headers, payload)
 
     def summarizeTable(
         self, db_branch_name: str, table_name: str, payload: dict
@@ -889,14 +911,15 @@ class Search_and_filter(Namespace):
                path: /db/{db_branch_name}/tables/{table_name}/summarize
                method: POST
 
-               :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`.
-               :param table_name: str The Table name
-               :param payload: dict Request Body
+               :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
+               :param table_name: str The Table name [in: path, req: True]
+               :param payload: dict content [in: requestBody, req: True]
+
                :return Response
         """
         url_path = f"/db/{db_branch_name}/tables/{table_name}/summarize"
         headers = {"content-type": "application/json"}
-        return self.request("POST", url_path, payload, headers)
+        return self.request("POST", url_path, headers, payload)
 
     def aggregateTable(
         self, db_branch_name: str, table_name: str, payload: dict
@@ -913,11 +936,12 @@ class Search_and_filter(Namespace):
                path: /db/{db_branch_name}/tables/{table_name}/aggregate
                method: POST
 
-               :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`.
-               :param table_name: str The Table name
-               :param payload: dict Request Body
+               :param db_branch_name: str The DBBranchName matches the pattern `{db_name}:{branch_name}`. [in: path, req: True]
+               :param table_name: str The Table name [in: path, req: True]
+               :param payload: dict content [in: requestBody, req: True]
+
                :return Response
         """
         url_path = f"/db/{db_branch_name}/tables/{table_name}/aggregate"
         headers = {"content-type": "application/json"}
-        return self.request("POST", url_path, payload, headers)
+        return self.request("POST", url_path, headers, payload)
